[CalendarServer-changes] [1503] CalendarServer/trunk/twistedcaldav

source_changes at macosforge.org source_changes at macosforge.org
Fri Apr 27 18:07:44 PDT 2007


Revision: 1503
          http://trac.macosforge.org/projects/calendarserver/changeset/1503
Author:   dreid at apple.com
Date:     2007-04-27 18:07:43 -0700 (Fri, 27 Apr 2007)

Log Message:
-----------
Rename the option because we actually support deflate & gzip though it's only one response filter (sorry no compress support)

Modified Paths:
--------------
    CalendarServer/trunk/twistedcaldav/config.py
    CalendarServer/trunk/twistedcaldav/root.py

Modified: CalendarServer/trunk/twistedcaldav/config.py
===================================================================
--- CalendarServer/trunk/twistedcaldav/root.py	2007-04-27 22:20:45 UTC (rev 1502)
+++ CalendarServer/trunk/twistedcaldav/root.py	2007-04-28 01:07:43 UTC (rev 1503)
@@ -53,7 +53,7 @@
 
         self.contentFilters = []
 
-        if config.GZipEncoding:
+        if config.ResponseCompression:
             from twisted.web2.filter import gzip
             self.contentFilters.append((gzip.gzipfilter, True))
 

-------------- next part --------------
An HTML attachment was scrubbed...
URL: http://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20070427/d1e6cdc8/attachment.html


More information about the calendarserver-changes mailing list
--- CalendarServer/trunk/twistedcaldav/config.py	2007-04-27 22:20:45 UTC (rev 1502)
+++ CalendarServer/trunk/twistedcaldav/config.py	2007-04-28 01:07:43 UTC (rev 1503)
@@ -177,8 +177,9 @@
     # crypto operations and shared by multiple server processes
     "SharedSecret": "",
 
-    # Support for the gzip Content-Encoding as specified in RFC2616 Section 3.5
-    "GZipEncoding": True,
+    # Support for Content-Encoding compression options as specified in
+    # RFC2616 Section 3.5
+    "ResponseCompression": True,
 }
 
 class Config (object):

Modified: CalendarServer/trunk/twistedcaldav/root.py
===================================================================